@@ -9,12 +9,20 @@ from ...common.background import BackgroundFormMixin
 from ...common.responsive import ResponsiveFormMixin
 from ...common.spacing import SpacingFormMixin
 from ...fields import AttributesFormField, IconGroup, TagTypeFormField
+from ...helpers import first_choice
 from ...models import FrontendUIItem
+from .. import content
 from .constants import CODE_TYPE_CHOICES
 
+mixin_factory = settings.get_forms(content)
+
 
 class CodeForm(
-    SpacingFormMixin, ResponsiveFormMixin, BackgroundFormMixin, EntangledModelForm
+    mixin_factory("Code"),
+    SpacingFormMixin,
+    ResponsiveFormMixin,
+    BackgroundFormMixin,
+    EntangledModelForm,
 ):
     """
     Content > "Code" Plugin
@@ -40,7 +48,7 @@ class CodeForm(
     code_type = forms.ChoiceField(
         label=_("Code type"),
         choices=CODE_TYPE_CHOICES,
-        initial=CODE_TYPE_CHOICES[0][0],
+        initial=first_choice(CODE_TYPE_CHOICES),
         required=True,
     )
     attributes = AttributesFormField()
@@ -48,7 +56,11 @@ class CodeForm(
 
 
 class BlockquoteForm(
-    SpacingFormMixin, ResponsiveFormMixin, BackgroundFormMixin, EntangledModelForm
+    mixin_factory("Blockquote"),
+    SpacingFormMixin,
+    ResponsiveFormMixin,
+    BackgroundFormMixin,
+    EntangledModelForm,
 ):
     """
     Content > "Blockquote" Plugin
@@ -89,7 +101,11 @@ class BlockquoteForm(
 
 
 class FigureForm(
-    SpacingFormMixin, ResponsiveFormMixin, BackgroundFormMixin, EntangledModelForm
+    mixin_factory("Figure"),
+    SpacingFormMixin,
+    ResponsiveFormMixin,
+    BackgroundFormMixin,
+    EntangledModelForm,
 ):
     """
     Content > "Figure" Plugin
