@@ -1,11 +1,12 @@
 from entangled.forms import EntangledModelForm
 
-from djangocms_frontend.fields import AttributesFormField
+from djangocms_frontend.fields import AttributesFormField, TagTypeFormField
 
+from ...common.responsive import ResponsiveFormMixin
 from ...models import FrontendUIItem
 
 
-class MediaForm(EntangledModelForm):
+class MediaForm(ResponsiveFormMixin, EntangledModelForm):
     """
     Layout > "Media" Plugin
     http://getbootstrap.com/docs/4.0/layout/media-object/
@@ -21,6 +22,7 @@ class MediaForm(EntangledModelForm):
         untangled_fields = ("tag_type",)
 
     attributes = AttributesFormField()
+    tag_type = TagTypeFormField()
 
 
 class MediaBodyForm(EntangledModelForm):
@@ -39,3 +41,4 @@ class MediaBodyForm(EntangledModelForm):
         untangled_fields = ("tag_type",)
 
     attributes = AttributesFormField()
+    tag_type = TagTypeFormField()
