@@ -1,13 +1,25 @@
 from django import forms
+from django.core.exceptions import ValidationError
 from django.utils.translation import gettext as _
 from entangled.forms import EntangledModelForm
 
 from ... import settings
-from ...fields import AttributesFormField, ButtonGroup, IconGroup, TagTypeFormField
+from ...common.spacing import SpacingFormMixin
+from ...fields import (
+    AttributesFormField,
+    ButtonGroup,
+    ColoredButtonGroup,
+    IconGroup,
+    TagTypeFormField,
+)
+from ...helpers import first_choice
 from ...models import FrontendUIItem
+from .. import utilities
+
+mixin_factory = settings.get_forms(utilities)
 
 
-class SpacingForm(EntangledModelForm):
+class SpacingForm(mixin_factory("Spacing"), EntangledModelForm):
     class Meta:
         model = FrontendUIItem
         entangled_fields = {
@@ -24,20 +36,20 @@ class SpacingForm(EntangledModelForm):
     space_property = forms.ChoiceField(
         label=_("Property"),
         choices=settings.SPACER_PROPERTY_CHOICES,
-        initial=settings.SPACER_PROPERTY_CHOICES[0][0],
+        initial=first_choice(settings.SPACER_PROPERTY_CHOICES),
         widget=ButtonGroup(attrs=dict(property="text")),
     )
     space_sides = forms.ChoiceField(
         label=_("Sides"),
         choices=settings.SPACER_SIDE_CHOICES,
-        initial=settings.SPACER_SIDE_CHOICES[0][0],
+        initial=first_choice(settings.SPACER_SIDE_CHOICES),
         required=False,
         widget=ButtonGroup(attrs=dict(property="text")),
     )
     space_size = forms.ChoiceField(
         label=_("Size"),
         choices=settings.SPACER_SIZE_CHOICES + (("auto", _("Auto")),),
-        initial=settings.SPACER_SIZE_CHOICES[0][0],
+        initial=first_choice(settings.SPACER_SIZE_CHOICES),
         widget=ButtonGroup(attrs=dict(property="text")),
     )
     space_device = forms.ChoiceField(
@@ -50,8 +62,27 @@ class SpacingForm(EntangledModelForm):
     attributes = AttributesFormField()
     tag_type = TagTypeFormField()
 
+    def clean(self):
+        super().clean()
+        if (
+            self.cleaned_data["space_property"] == "p"
+            and self.cleaned_data["space_size"] == "auto"
+        ):
+            raise ValidationError(
+                {
+                    "space_property": _(
+                        "Padding does not have an auto spacing. Either "
+                        "switch to margin or a defined size."
+                    ),
+                    "space_size": _(
+                        "Padding does not have an auto spacing. Either "
+                        "switch to a defined size or change the spacing property."
+                    ),
+                }
+            )
 
-class HeadingForm(EntangledModelForm):
+
+class HeadingForm(mixin_factory("Heading"), SpacingFormMixin, EntangledModelForm):
     class Meta:
         model = FrontendUIItem
         entangled_fields = {
@@ -59,6 +90,8 @@ class HeadingForm(EntangledModelForm):
                 "heading_level",
                 "heading",
                 "heading_id",
+                "heading_context",
+                "heading_alignment",
                 "attributes",
             ],
         }
@@ -71,6 +104,11 @@ class HeadingForm(EntangledModelForm):
         ("h4", _("Heading 4")),
         ("h5", _("Heading 5")),
     )
+    ALIGNMENT_CHOICES = (
+        ("start", _("Left")),
+        ("center", _("Center")),
+        ("end", _("Right")),
+    )
 
     heading_level = forms.ChoiceField(
         label=_("Heading level"),
@@ -90,10 +128,23 @@ class HeadingForm(EntangledModelForm):
             "Fill in unique ID for table of contents. If empty heading will not appear in table of contents."
         ),
     )
+    heading_context = forms.ChoiceField(
+        label=_("Heading context"),
+        required=False,
+        choices=settings.EMPTY_CHOICE + settings.COLOR_STYLE_CHOICES,
+        initial=settings.EMPTY_CHOICE,
+        widget=ColoredButtonGroup(),
+    )
+    heading_alignment = forms.ChoiceField(
+        label=_("Alignment"),
+        choices=settings.EMPTY_CHOICE + ALIGNMENT_CHOICES,
+        required=False,
+        widget=IconGroup(),
+    )
     attributes = AttributesFormField()
 
 
-class TableOfContentsForm(EntangledModelForm):
+class TableOfContentsForm(mixin_factory("TableOfContents"), EntangledModelForm):
     class Meta:
         model = FrontendUIItem
         entangled_fields = {
