@@ -1,10 +1,12 @@
 from django import forms
 from django.core.exceptions import ValidationError
 from django.db import models
+from django.utils.safestring import mark_safe
 from django.utils.translation import gettext_lazy as _
 from djangocms_attributes_field import fields
 
 from . import settings
+from .helpers import first_choice
 
 
 class ButtonGroup(forms.RadioSelect):
@@ -95,6 +97,47 @@ class AttributesFormField(fields.AttributesFormField):
         super().__init__(*args, **kwargs)
 
 
+try:
+    fields.AttributesWidget(
+        sorted=True
+    )  # does djangocms-attributes-field support sorted param?
+    CHOICESWIDGETPARAMS = dict(sorted=False)  # use unsorted variant
+except TypeError:
+    CHOICESWIDGETPARAMS = dict()  # Fallback for djangocms-attributes-field < 2.1
+
+
+class ChoicesFormField(fields.AttributesFormField):
+    """Simple choices field based on attributes field. Needs to be extended to
+    allow to sort choices"""
+
+    def __init__(self, *args, **kwargs):
+        kwargs.setdefault("label", _("Choices"))
+        kwargs.setdefault("required", True)
+        kwargs.setdefault("widget", fields.AttributesWidget(**CHOICESWIDGETPARAMS))
+        self.excluded_keys = kwargs.pop("excluded_keys", [])
+        super().__init__(*args, **kwargs)
+
+    def clean(self, value):
+        if not value:
+            raise ValidationError(
+                mark_safe(
+                    _(
+                        "Please enter at least one choice. Use the <code>+</code> symbol to add a choice."
+                    )
+                ),
+                code="empty",
+            )
+        return [(key, value) for key, value in value.items()]
+
+    def prepare_value(self, value):
+        if not value:
+            return {}
+        if isinstance(value, dict):  # Already dict? OK!
+            return super().prepare_value(value)
+        # Turn items into dict
+        return super().prepare_value({key: value for key, value in value})
+
+
 class TagTypeField(models.CharField):
     def __init__(self, *args, **kwargs):
         if "verbose_name" not in kwargs:
@@ -102,7 +145,7 @@ class TagTypeField(models.CharField):
         if "choices" not in kwargs:
             kwargs["choices"] = settings.TAG_CHOICES
         if "default" not in kwargs:
-            kwargs["default"] = settings.TAG_CHOICES[0][0]
+            kwargs["default"] = first_choice(settings.TAG_CHOICES)
         if "max_length" not in kwargs:
             kwargs["max_length"] = 255
         if "help_text" not in kwargs:
@@ -114,7 +157,16 @@ class TagTypeFormField(forms.ChoiceField):
     def __init__(self, *args, **kwargs):
         kwargs.setdefault("label", _("Tag type"))
         kwargs.setdefault("choices", settings.TAG_CHOICES)
-        kwargs.setdefault("initial", settings.TAG_CHOICES[0][0])
+        kwargs.setdefault("initial", first_choice(settings.TAG_CHOICES))
         kwargs.setdefault("required", False)
         kwargs.setdefault("widget", ButtonGroup(attrs=dict(property="text")))
         super().__init__(*args, **kwargs)
+
+
+class AutoNumberInput(forms.NumberInput):
+    class Media:
+        js = ("djangocms_frontend/js/auto_input.js",)
+
+    def __init__(self, *args, **kwargs):
+        kwargs.setdefault("attrs", {"class": "auto-field"})
+        super().__init__(*args, **kwargs)
