@@ -65,19 +65,17 @@ JUMBOTRON_TEMPLATE_CHOICES = getattr(
     ],
 )
 
-
-IMAGE_POSITIONING = (
-    ("center center", _("Fully Centered")),
-    ("left top", _("Top left")),
-    ("center top", _("Top center")),
-    ("right top", _("Top right")),
-    ("left center", _("Center left")),
-    ("right center", _("Center right")),
-    ("left bottom", _("Bottom left")),
-    ("center bottom", _("Bottom center")),
-    ("right bottom", _("Bottom right")),
+NAVIGATION_TEMPLATE_CHOICES = getattr(
+    settings,
+    "DJANGOCMS_FRONTEND_NAVIGATION_TEMPLATE_CHOICES",
+    [
+        ("default", _("Default")),
+    ],
 )
 
+FORM_OPTIONS = getattr(settings, "DJANGOCMS_FRONTEND_FORM_OPTIONS", {})
+
+
 framework = getattr(settings, "DJANGOCMS_FRONTEND_FRAMEWORK", "bootstrap5")
 theme = getattr(settings, "DJANGOCMS_FRONTEND_THEME", "djangocms_frontend")
 
@@ -97,6 +95,7 @@ SPACER_X_SIDES_CHOICES = framework_settings.SPACER_X_SIDES_CHOICES
 SPACER_Y_SIDES_CHOICES = framework_settings.SPACER_Y_SIDES_CHOICES
 SIZE_X_CHOICES = framework_settings.SIZE_X_CHOICES
 SIZE_Y_CHOICES = framework_settings.SIZE_Y_CHOICES
+NAVBAR_DESIGNS = framework_settings.NAVBAR_DESIGNS
 
 FRAMEWORK_PLUGIN_INFO = getattr(framework_settings, "FRAMEWORK_PLUGIN_INFO", dict())
 
