@@ -24,19 +24,34 @@ INSTALLED_APPS = [
     "djangocms_frontend.contrib.carousel",
     "djangocms_frontend.contrib.collapse",
     "djangocms_frontend.contrib.content",
+    "djangocms_frontend.contrib.forms",
     "djangocms_frontend.contrib.grid",
     "djangocms_frontend.contrib.jumbotron",
     "djangocms_frontend.contrib.link",
     "djangocms_frontend.contrib.listgroup",
     "djangocms_frontend.contrib.media",
+    "djangocms_frontend.contrib.navigation",
     "djangocms_frontend.contrib.image",
     "djangocms_frontend.contrib.tabs",
     "djangocms_frontend.contrib.utilities",
+    "sekizai",
 ]
 
 if DJANGO_3_1:
     INSTALLED_APPS += ["django_jsonfield_backport"]
 
+try:  # V4 test?
+    import djangocms_versioning  # noqa
+
+    INSTALLED_APPS += [
+        "djangocms_versioning",
+        "djangocms_alias",
+        "djangocms_url_manager",
+        "djangocms_pageadmin",
+        "djangocms_version_locking",
+    ]
+except ImportError:  # Nope
+    pass
 
 MIDDLEWARE = [
     "django.contrib.sessions.middleware.SessionMiddleware",
